You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@aries.apache.org by da...@apache.org on 2013/02/22 16:32:01 UTC

svn commit: r1449076 - /aries/trunk/versioning/versioning-checker/src/main/java/org/apache/aries/versioning/check/BundleCompatibility.java

Author: davidb
Date: Fri Feb 22 15:32:00 2013
New Revision: 1449076

URL: http://svn.apache.org/r1449076
Log:
Remove reference to WAS, replace by 'this bundle'.

Modified:
    aries/trunk/versioning/versioning-checker/src/main/java/org/apache/aries/versioning/check/BundleCompatibility.java

Modified: aries/trunk/versioning/versioning-checker/src/main/java/org/apache/aries/versioning/check/BundleCompatibility.java
URL: http://svn.apache.org/viewvc/aries/trunk/versioning/versioning-checker/src/main/java/org/apache/aries/versioning/check/BundleCompatibility.java?rev=1449076&r1=1449075&r2=1449076&view=diff
==============================================================================
--- aries/trunk/versioning/versioning-checker/src/main/java/org/apache/aries/versioning/check/BundleCompatibility.java (original)
+++ aries/trunk/versioning/versioning-checker/src/main/java/org/apache/aries/versioning/check/BundleCompatibility.java Fri Feb 22 15:32:00 2013
@@ -282,7 +282,7 @@ public class BundleCompatibility {
       if ((cd != null) && (!SemanticVersioningUtils.isPropertyFile(cd))) {
 
         if (curFile == null) {
           // the class we are scanning has been deleted from the current version of WAS
           // This should be a major increase
           major_reason.append(twoLineBreaks + "The class/interface " + getClassName(changeClass) + " has been deleted from the package.");
           //majorChange.update(reason, changeClass);
@@ -293,7 +293,7 @@ public class BundleCompatibility {
           }
         } else {
           // check for binary compatibility
           // load the class from the current version of WAS
           // remove it from the curClazz collection as we would like to know whether there are more classes added
           curClazz.remove(file.getKey());
           SemanticVersioningClassVisitor newcv = getVisitor(curFile, newJarsLoader);
@@ -349,10 +349,10 @@ public class BundleCompatibility {
               }
               if (containsAbstract) {
 
-                minor_reason.append(twoLineBreaks + "In the " + getClassName(changeClass) + " class or its supers, the following abstract methods have been added since the last release of WAS.");
+                minor_reason.append(twoLineBreaks + "In the " + getClassName(changeClass) + " class or its supers, the following abstract methods have been added since the last release of this bundle.");
                 minor_reason.append(subRemarks);
               } else {
-                minor_reason.append(twoLineBreaks + "In the " + getClassName(changeClass) + " class or its supers, the following method has been added since the last release of WAS.");
+                minor_reason.append(twoLineBreaks + "In the " + getClassName(changeClass) + " class or its supers, the following method has been added since the last release of this bundle.");
                 minor_reason.append(concreteSubRemarks);
               }
             }
@@ -366,7 +366,7 @@ public class BundleCompatibility {
                   if (!is_major_change) {
                     fatal_class = changeClass;
                   }
-                  minor_reason.append(twoLineBreaks + "In the " + getClassName(changeClass) + " class or its supers, the following fields have been added since the last release of WAS.");
+                  minor_reason.append(twoLineBreaks + "In the " + getClassName(changeClass) + " class or its supers, the following fields have been added since the last release of this bundle.");
                   minor_reason.append(extraFieldRemarks);
                   break;
                 }
@@ -282,7 +282,7 @@ public class BundleCompatibility {
 
         if (curFile == null) {
-          // the class we are scanning has been deleted from the current version of WAS
+          // the class we are scanning has been deleted from the current version of the bundle
           // This should be a major increase
           major_reason.append(twoLineBreaks + "The class/interface " + getClassName(changeClass) + " has been deleted from the package.");
@@ -293,7 +293,7 @@ public class BundleCompatibility {
         } else {
           // check for binary compatibility
-          // load the class from the current version of WAS
+          // load the class from the current version of the bundle
           // remove it from the curClazz collection as we would like to know whether there are more classes added
           curClazz.remove(file.getKey());